import m3u8, json
from requests import get
from bs4 import BeautifulSoup

MASTER_URL = 'http://dcunilive30-lh.akamaihd.net/i/dclive_1@535498/master.m3u8'
CALENDAR_URL = 'http://tv.parliament.qld.gov.au/TV/PartialCalendar'

class Stream(object):
    @property
    def is_live(self):
        try:
            self.m3u8_data = m3u8.parse(get(MASTER_URL).text)
            if(self.m3u8_data['playlists']):
                return True
            else:
                return False
        except:
            return False

    @property
    def stream_url(self):
        if(self.is_live):
            print(self.m3u8_data)
            #return(self.m3u8_data['playlists'][-1]['uri'])
        else:
            return ''

    @property
    def stream_title(self):
        if(self.is_live):
            soup = BeautifulSoup(get(CALENDAR_URL).text, 'lxml')
            try:
                return(soup.find_all('h3')[-1].text.strip())
            except:
                return ''
        else:
            return ''

    @property
    def stream_urls(self):
        if(self.is_live):
            return {self.stream_title: self.stream_url}
        else:
            return {}


import m3u8, json
from requests import get

base = 'http://pbs1.nt.gov.au/HLS/HDPull/'
stream_url = base + 'playlist.m3u8'

class Stream(object):
    @property
    def lower_is_live(self):
        stream_segments = m3u8.parse(get(stream_url).text)['segments']
        seg_lens = []
        for i in range(3):
            seg_lens.append(len(get(base + stream_segments[-(i + 1)]['uri']).content))
        if(any(seg_lens.count(element) > 1 for element in seg_lens)):
            return False
        else:
            return True
    
    @property
    def lower_stream_url(self):
        return stream_url

    @property
    def stream_urls(self):
        return({'lower': self.lower_stream_url})